<?php
/**
 * Blocks Initializer
 *
 * Enqueue CSS/JS of all the blocks.
 *
 * @since   1.0.0
 * @package CGB
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Enqueue Gutenberg block assets for both frontend + backend.
 *
 * Assets enqueued:
 * 1. blocks.style.build.css - Frontend + Backend.
 * 2. blocks.build.js - Backend.
 * 3. blocks.editor.build.css - Backend.
 *
 * @uses {wp-blocks} for block type registration & related functions.
 * @uses {wp-element} for WP Element abstraction — structure of blocks.
 * @uses {wp-i18n} to internationalize the block's text.
 * @uses {wp-editor} for WP editor styles.
 * @since 1.0.0
 */
function donatepress_block_cgb_block_assets() { // phpcs:ignore
	// Register block styles for both frontend + backend.
	wp_register_style(
		'donatepress_block-cgb-style-css', // Handle.
		plugins_url( 'dist/blocks.style.build.css', dirname( __FILE__ ) ), // Block style CSS.
		is_admin() ? array( 'wp-editor' ) : null, // Dependency to include the CSS after it.
		null // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.style.build.css' ) // Version: File modification time.
	);

	// Register block editor script for backend.
	wp_register_script(
		'donatepress_block-cgb-block-js', // Handle.
		plugins_url( '/dist/blocks.build.js', dirname( __FILE__ ) ), // Block.build.js: We register the block here. Built with Webpack.
		array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ), // Dependencies, defined above.
		null, // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.build.js' ), // Version: filemtime — Gets file modification time.
		true // Enqueue the script in the footer.
	);

	// Register block editor styles for backend.
	wp_register_style(
		'donatepress_block-cgb-block-editor-css', // Handle.
		plugins_url( 'dist/blocks.editor.build.css', dirname( __FILE__ ) ), // Block editor CSS.
		array( 'wp-edit-blocks' ), // Dependency to include the CSS after it.
		null // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.editor.build.css' ) // Version: File modification time.
	);

	// WP Localized globals. Use dynamic PHP stuff in JavaScript via `cgbGlobal` object.
	wp_localize_script(
		'donatepress_block-cgb-block-js',
		'cgbGlobal', // Array containing dynamic data for a JS Global.
		[
			'pluginDirPath' => plugin_dir_path( __DIR__ ),
			'pluginDirUrl'  => plugin_dir_url( __DIR__ ),
			// Add more data here that you want to access from `cgbGlobal` object.
		]
	);

	/**
	 * Register Gutenberg block on server-side.
	 *
	 * Register the block on server-side to ensure that the block
	 * scripts and styles for both frontend and backend are
	 * enqueued when the editor loads.
	 *
	 * @link https://wordpress.org/gutenberg/handbook/blocks/writing-your-first-block-type#enqueuing-block-scripts
	 * @since 1.16.0
	 */
	register_block_type(
		'cgb/block-donatepress-block', array(
			// Enqueue blocks.style.build.css on both frontend & backend.
			'style'         => 'donatepress_block-cgb-style-css',
			// Enqueue blocks.build.js in the editor only.
			'editor_script' => 'donatepress_block-cgb-block-js',
			// Enqueue blocks.editor.build.css in the editor only.
			'editor_style'  => 'donatepress_block-cgb-block-editor-css',
		)
	);
}

// Hook: Block assets.
add_action( 'init', 'donatepress_block_cgb_block_assets' );



if (!class_exists('Donatepress_Payment_Block')) {

    /**
     * Plugin main class.
     *
     * @package Donatepress_Payment_Block
     */
    class Donatepress_Payment_Block {

        /**
         * Plugin version.
         *
         * @var string
         */
        const VERSION = '1.0.0';

        /**
         * Instance of this class.
         *
         * @var object
         */
        protected static $instance = null;

        /**
         * Initialize the plugin public actions.
         */
        private function __construct() {
            add_action('init', array($this, 'pdb_load_plugin_textdomain'));
            add_shortcode('donatepress_payment_block', array($this, 'create_donatepress_block_shortcode'));
            add_filter('widget_text', 'do_shortcode');
        }

        /**
         * Return an instance of this class.
         *
         * @return object A single instance of this class.
         */
        public static function get_instance() {
            // If the single instance hasn't been set, set it now.
            if (null == self::$instance) {
                self::$instance = new self();
            }

            return self::$instance;
        }

        /**
         * Load the plugin text domain for translation.
         */
        public function pdb_load_plugin_textdomain() {
            load_plugin_textdomain('paypal-donation-block', false, dirname(plugin_basename(__FILE__)) . '/languages/');
        }

        public function create_donatepress_block_shortcode($atts) {
            $admin_email = get_option('admin_email');
            $atts = shortcode_atts(
                    array(
                        'email'    => $admin_email,
                        'currency' => 'USD',
                        'purpose'  => '',
                        'amount'   => '',
                        'size'     => 'temp3',
                        'mode'     => ''
                    ), $atts, 'bartag');


            switch ($atts['size']) {
                case 'temp1':
                    $imgurl = plugins_url( '/src/assets/img/1.png', dirname( __FILE__ ) );
                    break;
                case 'temp2':
                    $imgurl = plugins_url( '/src/assets/img/2.jpg', dirname( __FILE__ ) );
                    break;
                case 'temp3':
                    $imgurl = plugins_url( '/src/assets/img/3.gif', dirname( __FILE__ ) );
                    break;
                default:
                    $imgurl = 'https://www.paypal.com/en_US/i/btn/btn_donate_SM.gif';
            }
            $paypal_form_url = ( $atts['mode'] == "sandbox") ? "https://www.sandbox.paypal.com/cgi-bin/webscr" : "https://www.paypal.com/cgi-bin/webscr";

            return '<form  target="_blank" action="'.$paypal_form_url.'" method="post">
    			<div class="Donatepress_Payment_Block">
			        <input type="hidden" name="cmd" value="_donations">
                    <input type="hidden" name="item_name" value="' . $atts['purpose'] . '">
                    <input type="hidden" name="amount" value="' . $atts['amount'] . '">
			        <input type="hidden" name="business" value="' . $atts['email'] . '">
			        <input type="hidden" name="rm" value="0">
			        <input type="hidden" name="currency_code" value="' . $atts['currency'] . '">
			        <input type="image" class="dontepress_tem" src="' . $imgurl . '" name="submit" alt="PayPal - The safer, easier way to pay online.">
			        <img alt="" src="https://www.paypal.com/en_US/i/scr/pixel.gif" width="1" height="1">
			    </div>
			</form>';
        }

    }

    add_action('plugins_loaded', array('Donatepress_Payment_Block', 'get_instance'));
}